/*
 * %kadu copyright begin%
 * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "message/message-filter-service.h"
#include "services/message-transformer-service.h"
#include "services/raw-message-transformer-service.h"

#include "chat-service.h"

ChatService::ChatService(Account account, QObject *parent) :
		AccountService(account, parent)
{
}

ChatService::~ChatService()
{
}

void ChatService::setRawMessageTransformerService(RawMessageTransformerService *rawMessageTransformerService)
{
	m_rawMessageTransformerService = rawMessageTransformerService;
}

RawMessageTransformerService * ChatService::rawMessageTransformerService() const
{
	return m_rawMessageTransformerService.data();
}

#include "moc_chat-service.cpp"
